#!/bin/sh
#------------------------------------------------------------------------------
# /var/www/htdocs/motion/motion-tree.cgi - tree cgi-script of motion web gui
#
# Copyright (C) 2002 Jeroen Vreeken (pe1rxq@amsat.org)
# Copyright (c) 2008-2011 The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2007-09-05  jed
# Last Update:  $Id: motion-tree.cgi 29116 2011-11-14 14:34:37Z jed $
#
# Creates a tree representation of a directory with files generated by motion.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

#exec 2>/tmp/motion-tree-trace-$$.log
#set -x

# load eislib etc.
. /var/install/include/check-eisfair-version

# set platform specific parameters
case ${EISFAIR_SYSTEM} in
    eisfair-1)
        # eisfair-1
        motionconfig_path=/var/motion
        ;;
    *)
        # default to eisfair-2
        motionconfig_path=/data/packages/motion
        ;;
esac

ABSOLUTEPATH=`grep "^ABSOLUTEPATH" ${motionconfig_path}/motion-cgi.conf | cut -d'=' -f 2-`
CAMERAPATH=`grep "^CAMERAPATH" ${motionconfig_path}/motion-cgi.conf | cut -d'=' -f 2-`
IMAGEDIR=`grep "^IMAGEDIR" ${motionconfig_path}/motion-cgi.conf | cut -d'=' -f 2`

echo Content-type: text/html
echo "refresh: 600; url=${REQUEST_URI}"
echo

SOURCE=`echo ${QUERY_STRING} | cut -d'?' -f1`
YEAR=`echo   ${QUERY_STRING} | cut -d'?' -f2`
MONTH=`echo  ${QUERY_STRING} | cut -d'?' -f3`
DAY=`echo    ${QUERY_STRING} | cut -d'?' -f4`
HOUR=`echo   ${QUERY_STRING} | cut -d'?' -f5`
MINUTE=`echo ${QUERY_STRING} | cut -d'?' -f6`
SECOND=`echo ${QUERY_STRING} | cut -d'?' -f5 | cut -c5-6`

echo "<HTML>"
echo "<BODY bgcolor=#ffffdd>"

echo "<a href=http://www.lavrsen.dk/twiki/bin/view/Motion/WebHome target=_motion_home><IMG border=0 src=${IMAGEDIR}/motion-tux.gif></a>"
echo "<HR>"
echo "<B>SOURCE:</B> <I>${SOURCE}</I>"

if [ "${YEAR}" != "${SOURCE}" ]
then
    echo "| <B>DATE:</B>"
    echo "${YEAR}"
fi

if [ "${MONTH}" != "${SOURCE}" ]
then
    echo "- ${MONTH}"
fi

if [ "${DAY}" != "${SOURCE}" ]
then
    echo "- ${DAY}"
fi

if [ "${HOUR}" != "${SOURCE}" ]
then
    echo "| <B>TIME:</B>"
    echo "${HOUR}"
fi

if [ "${MINUTE}" != "${SOURCE}" ]
then
    echo ": ${MINUTE}"
fi

echo "<HR>"

optionslink()
{
    echo "["
    if [ "`echo ${1} | cut -d'.' -f2`" = "tgz" ] || [ "`echo ${1} | cut -d'.' -f3`" = "tgz" ]
    then
    echo "<I><A HREF=filehandle/motion-filehandle.cgi?extract?${1}>Extract</A></I>"
    else
        echo "<I><A HREF=filehandle/motion-filehandle.cgi?archive?${1}>Archive</A></I>"
    fi
    echo "|"
    echo "<I><A HREF=filehandle/motion-filehandle.cgi?remove?${1}>Remove</A></I>"
    echo "]"
}

treelink()
{
    echo "<B><A HREF="`echo ${REQUEST_URI}| cut -d'?' -f 1`"?${1}>${2}</A></B>"
}

for years in `find ${CAMERAPATH}/${SOURCE}/ -mindepth 1 -maxdepth 1 -printf '%f\n' | sort`
do
    echo "<ul>"
    if [ `echo ${years} | cut -d'.' -f 2` = "jpg" ]
    then
        echo "jpg image:"
        echo "<A href=${CAMERAPATH}/${SOURCE}/${years} target=view_window>${years}</a>"
    else
        if [ `echo ${years} | cut -d'.' -f 2` = "ppm" ]
        then
            echo "ppm image:"
            echo "<A href=${CAMERAPATH}/${SOURCE}/${years} target=view_window>${years}</a>"
        else
            treelink ${SOURCE}?${years} ${years}
        fi
    fi

    optionslink ${SOURCE}/${years}

    if [ "${years}" = "${YEAR}" ]
    then
        for months in `find ${CAMERAPATH}/${SOURCE}/${YEAR} -mindepth 1 -maxdepth 1 -printf '%f\n'| sort`
        do
            echo "<ul>"
            treelink ${SOURCE}?${years}?${months} ${months}
            optionslink ${SOURCE}/${years}/${months}

            if [ ${months} = ${MONTH} ]
            then
                for days in `find ${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH} -mindepth 1 -maxdepth 1 -printf '%f\n' | sort`
                do
                    echo "<ul>"
                    if [ `echo ${days} | cut -d'.' -f 2` = "mpg" ]
                    then
                        echo "mpeg movie:"
                        echo "<A href="${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${days}" target=view_window>${days}</A>"
                    else
                        treelink ${SOURCE}?${years}?${months}?${days} ${days}
                    fi

                    optionslink ${SOURCE}/${years}/${months}/${days}
            
                    if [ "${days}" = "${DAY}" ]
                    then
                        for hours in `find ${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${DAY} -mindepth 1 -maxdepth 1 -printf '%f\n' | sort`
                        do
                            echo "<ul>"
                            if [ `echo ${hours} | cut -d'.' -f 2` = "avi" ]
                            then
                                echo "avi movie:"
                                echo "<A href=${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${DAY}/${hours} target=view_window>${hours}</A>"
                            else
                                treelink ${SOURCE}?${years}?${months}?${days}?${hours} ${hours}
                            fi
                            optionslink ${SOURCE}/${years}/${months}/${days}/${hours}

                            if [ "${hours}" = "${HOUR}" ]
                            then
                                for minutes in `find ${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${DAY}/${HOUR} -mindepth 1 -maxdepth 1 -printf '%f\n' | sort`
                                do
                                    echo "<ul>"
                                    treelink ${SOURCE}?${years}?${months}?${days}?${hours}?${minutes} ${minutes}
                                    optionslink ${SOURCE}/${years}/${months}/${days}/${hours}/${minutes}

                                    if [ "${minutes}" = "${MINUTE}" ]
                                    then
                                        for seconds in `find ${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${DAY}/${HOUR}/${MINUTE} -mindepth 1 -maxdepth 1 -printf '%f\n' | sort`
                                        do
                                            echo "<ul>"
                                            if [ `echo ${seconds} | cut -d'.' -f 2` = "jpg" ]
                                            then
                                                echo "jpeg image:"
                                                echo "<A href=${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${DAY}/${HOUR}/${MINUTE}/${seconds} target=view_window>${seconds}</a>"
                                            else
                                                if [ `echo ${seconds} | cut -d'.' -f 2` = "ppm" ]
                                                then
                                                    echo "ppm image:"
                                                    echo "<A href=${CAMERAPATH}/${SOURCE}/${YEAR}/${MONTH}/${DAY}/${HOUR}/${MINUTE}/${seconds} target=view_window>${seconds}</a>"
                                                else
                                                    echo "${seconds}"
                                                fi
                                            fi

                                            optionslink ${SOURCE}/${years}/${months}/${days}/${hours}/${minutes}/${seconds}
                                            echo "</ul>"
                                        done
                                    fi
                                    echo "</ul>"
                                done
                            fi
                            echo "</ul>"
                        done
                    fi
                    echo "</ul>"
                done
            fi
            echo "</ul>"
        done
    fi
    echo "</ul>"
done

echo "<HR>"
echo "<A href=${REQUEST_URI}>Reload</A>"
echo "<HR><H6><I>"
echo "Generated on " `date` " by ${SERVER_NAME}"
echo "</BODY>"
echo "</HTML>"
